/*!
 * YJ Media Slider
 * @version		1.0.3
 * @author Youjoomla.com
 * Copyright Youjoomla.com
 */
;(function($){
	
	$.fn.YJ_MediaSlider = function( options ){
		
		// if no element is found, bail out
		if( 0 == this.length ){ 
			return false; 
		}		
		// support multiple elements
       	if (this.length > 1){
            this.each(function() { 
				$(this).YJ_MediaSlider(options);				
			});
            return this;
       	}
		
       	// variables
		var defaults = {
			slides 			: '.slide', // slide CSS class selector
			poster 			: 'img.poster', // poster image CSS selector
			video 			: '.play-video', // element within slide that has video data on it
			video_container	: '.video-player', // element that holds video players
			// navigation
			nav		: {
				back 		: '.main-nav .prev',
				fwd			: '.main-nav .next',
				container 	: '.main-nav'
			},
			navholder		: '.yjmediaout',
			individual_nav	: '.secondary-nav .individual-nav li a',
			animateChildren	: '.slide-details', // children of the element specified here will be animated
			autoSlide		: $(options.navholder).data('autoslide'), // how much should a slide stay on (milliseconds) - if false, no autoslide
			pauseOnHover 	: true, // stop automatic sliding while mouse is over			
			animationDuration : 900,
			animationType	: 'slide', // slide or fade
			is_iDevice		: null,
			dimlights		: 1,
			dimOpacity		: 0.8,
			dimContainer	:'dim_lights'
		};
		
		var self 			= this,
			options 		= $.extend({}, defaults, options),
			slides 			= false, // store slides
			prev 			= $(this).find( options.nav.back ), // previous slide navigation element
			next			= $(this).find( options.nav.fwd ), // next slide navigation element
			navContainer	= $(this).find( options.nav.container ), // main navigation container
			video_container = $(this).find( options.video_container ), // video container
			currentSlide	= 0, // current visible slide index
			switchingSlides	= {'current' : false, 'next' : false}, // store slide that must be loaded
			interval		= false, // automatic slide interval reference
			youtube_player	= false, // youtube player reference
			vimeo_player	= false, // vimeo player reference
			video_playing	= false, // while playing a video variable is true
			video_paused	= false,
			video_aspect	= false, // store currently playing video aspect
			video_source	= false, // changed here
			firstAnimationComplete = false, // first page load animation is complete
			singleNavs		= false,
			animation		= 'slide' == options.animationType ? 'slide' : 'fade',
			animation_running = false; // store one by one navigation elements
		
		if( options.autoSlide && options.autoSlide > 0 ){
			options.autoSlide += options.animationDuration||500;
		}
		
		var initialize = function(){
			// get slides
			slides = $(self).find( options.slides );
			// set slide height based on poster
			$.each( slides, function( i ){
				
				if( options.animateChildren ){
					var parent = $(this).find(options.animateChildren),
						children = $(parent).children();
					$(this).data('animate', {'parent' : parent, 'children' : children});
				}
				
				// process videos
				var video_link = $(this).find( options.video );
				$(video_link).click( function(e){
					e.preventDefault();
					playVideo( $(video_link).data() );
					self.rearangeMainNav();
				});
				
				$(self).mouseenter(function(){
					if( video_playing ){
						$(navContainer).stop(true, true, true).animate({'opacity':1}, {queue:false, duration:200});
					}
				}).mouseleave(function(){
					if( video_playing ){
						if( !$.browser.mobile ){
							$(navContainer).stop(true, true, true).animate({'opacity':0}, {queue:false, duration:200});
						}else if( !video_paused ){						
							$(navContainer).stop(true, true, true).animate({'opacity':0}, {queue:false, duration:200});
						}	
					}
				});
				
				// process poster images
				var poster = $(this).find( options.poster );
				if( poster.length == 0 ){
					return;
				}
				// poster height
				var h = $(poster).height();
				// if first slide, set height on slider
				if( 0 == i ){
					
					$(self).removeClass('loading').stop(true, true, true).animate({'height':h}, {queue:false, duration:300});					
					$(this).css({'z-index':5, 'opacity':0, 'visibility':'visible'}).stop(true, true, true).animate({'opacity':1}, {'queue':false, duration:options.animationDuration||500, complete: function(){
						// start autoslide when first slide animation is complete
						firstAnimationComplete = true;
						startSlider();
					}});
				}else{
					$(this).css({'opacity':0, 'z-index':1});
				}
				
				$(this).css({
					'position' 		: 'absolute',
					'visibility'	: 'visible',
					'top'		: 0,
					'left'		: 0
				})
				
				// store height on slide
				$( this ).data( 'height', h ).css('height', h);
				$( this ).data( 'poster', poster );
			}); // end loop
			
			$('.slides').resize(function(){
				$.each(slides, function(i){
					var h = $(this).data('poster').height();
					$( this ).data( 'height', h ).css('height', h);
					if( currentSlide == i && !video_playing ){
						$(self).css('height', h);
					}
				});
				
				if( video_playing ){
					var w = $(self).width();
					if( video_aspect ){
						var include_controls = 'youtube' == video_source ? 35 : 0; // changed here
						switch( video_aspect ){
							case '16x9':
								$(self).css('height', (w * 9 / 16 + include_controls)); // changed here
							break;
							case '4x3':
								$(self).css('height', (w * 3 / 4 + include_controls)); // changed here
							break;	
						}
					}					
				}				
			});
			
			// Main navigation
			$(prev).click(function(e){
				e.preventDefault();
				e.stopPropagation();
				resetSlider();
				prevSlide();
				stopVideo();
			});			
			$(next).click(function(e){
				e.preventDefault();
				e.stopPropagation();
				resetSlider();
				nextSlide();
				stopVideo();
			});
			// end of main navigation
			
			$(self).swiperight(function(e){
				e.preventDefault();
				e.stopPropagation();
				
				if( animation_running ){
					return;
				}				
				resetSlider();
				prevSlide();
				stopVideo();
			}).swipeleft(function(e){
				e.preventDefault();
				e.stopPropagation();
				if( animation_running ){
					return;
				}
				resetSlider();
				nextSlide();
				stopVideo();
			})
			
			startNavigation();
			
			if( options.pauseOnHover ){
				// stop autoslide on mouse over
				$(self).mouseenter( stopSlider );
				$(self).mouseleave( startSlider );
			}
				
			return self;
		};
		
		var startNavigation = function(){
			if( !options.individual_nav ){
				return;
			}
			
			singleNavs = $(options.navholder).find( options.individual_nav );
			if( singleNavs.length > 0 ){
				$.each(singleNavs, function(i){
					if( i==currentSlide ){
						$(this).addClass('current');
					}
					
					$(this).click(function(e){
						e.preventDefault();
						resetSlider();
						gotoSlide(i);
						stopVideo();
					});					
				});
			}			
		}
		
		// start autoslide if set
		var startSlider = function(){
			if( !firstAnimationComplete || !options.autoSlide || options.autoSlide <= 0 ){
				return;
			}
			
			if( video_playing ){
				stopSlider();
				return;
			}
			
			if( !interval ){			
				// @todo - check if video is playing
				interval = setInterval( nextSlide , options.autoSlide || 3000 );
			}
		};
		
		// stop autoslide
		var stopSlider = function(){
			if( options.autoSlide && options.autoSlide > 0 ){			
				if( interval ){
					clearInterval( interval );
					interval = false;	
				}			
			}	
		};
		
		// simple slider reset if navigation is clicked
		var resetSlider = function(){
			stopSlider();
			startSlider();
		};
		
		// go to next slide
		var nextSlide = function(){
			var nextIndex = currentSlide + 1;
			if( nextIndex >= slides.length ){
				nextIndex = 0;
			}
			
			startAnimate(nextIndex);
			
			currentSlide = nextIndex;
			highlightNav(currentSlide);
		};
		
		// go to previous slide
		var prevSlide = function(){
			var prevIndex = currentSlide - 1;
			if( prevIndex < 0 ){
				prevIndex = slides.length - 1;				
			}
			
			startAnimate(prevIndex);
			
			currentSlide = prevIndex;
			highlightNav(currentSlide);	
		};
		
		// go to a given slide
		var gotoSlide = function(index){
			if( index < 0 || index >= slides.length ){
				return;
			}
			
			startAnimate(index);
			
			highlightNav(index);			
			currentSlide = index;	
		};
		
		// animates slides
		var startAnimate = function( index ){
			
			var is_slide 	= 'slide' == animation,
				left 		= ( index < currentSlide ? -1 : 1 ) * $(self).width();
			
			
			animation_running = true;
			
			var currentSlideChildren 	= $(slides[currentSlide]).data('animate'),
				nextSlideChildren 		= $(slides[index]).data('animate'),
				fxOut = {'margin-left':200, 'opacity' : 0},
				fxIn = {'margin-left':0, 'opacity' : 1};
			
			if( currentSlideChildren ){			
				$.each( currentSlideChildren.children, function(i){
					var d = 1000 * (i+1);
					$(this).stop(true, true, true).animate(fxOut, {queue:false, duration:d, easing: 'easeOutElastic'});
				});
				nextSlideChildren.children.css(fxOut);
			}	
			
			if( !video_playing ){
				$(slides[currentSlide])
				.stop(true, true, true)
				.animate( 
					{'opacity' : ( is_slide ? 1 : 0 ), 'left' : ( is_slide ? -left : 0 )}, 
					{queue:false, duration:options.animationDuration||500, complete: function(){
						$(this).css({'left': 0, 'opacity' : 0});
					}} 
				)
				.css('z-index',1);
			}else{
				$(slides[currentSlide])
					.css({'opacity':0, 'z-index' : 1, 'left' : 0});
			}
			
			$(slides[index])
				.css({'visibility':'visible', 'left' : ( is_slide ? left : 0 ), 'opacity' : ( is_slide ? 1 : 0 )})
				.stop(true, true, true)
				.animate({
					'opacity':1, 'left' : 0}, {queue:false, duration:options.animationDuration||500, complete: function(){
						
						if( nextSlideChildren ){
							$.each( nextSlideChildren.children, function(i){
								var d = 300 * (i+1);
								$(this).stop(true, true, true).animate(fxIn, {queue:false, duration:d, easing:'easeOutElastic', complete: function(){
									if( i == nextSlideChildren.children.length - 1 ){
										animation_running = false;
									}
								}});
							});
						}else{
							animation_running = false;
						}
						
					}})
				.css('z-index',5);	
			
			$(self).stop(true, true, true).animate({
				'height' : getSlideHeight(index)
			}, {'queue':false, 'duration':300});
			
			switchingSlides.current = currentSlide;
			switchingSlides.next = index;
		};
		
		// highlights a given index single navigation element
		var highlightNav = function(index){
			$(singleNavs).removeClass('current');
			$(singleNavs[index]).addClass('current');
		}
		
		// helpers
		var getSlideHeight = function(i){
			return $( slides[i] ).data('height');
		}
		
		// stops the currently playing video
		var stopVideo = function(){
			if( !video_playing ){
				return;
			}
			
			if( youtube_player ){
				youtube_player.stopVideo();
			}
			if( vimeo_player ){
				vimeo_player.stopVideo();
			}
		}
		
		var playVideo = function( data ){
			// stop the slider if running
			stopSlider();
			self.changeVideoStatus(true);
			var H = $(self).height();
			video_aspect = data.aspect;
			video_source = data.source; // changed here
			var include_controls = 'youtube' == data.source ? 35 : 0; // changed here
			
			switch( data.aspect ){
				case '16x9':
				default:	
					H = $(self).width() * (9 / 16) + include_controls; 
				break;
				case '4x3':
					H = $(self).width() * (3 / 4) + include_controls; 
				break;
			}
			
			$(self).stop(true, true, true).animate({
				'height': H
			}, {'queue':false, 'duration':300});
			
			// bring video container back into view
			$(video_container).css({
				'top'		: 0,
				'left'		: 0,
				'display'	: 'block',
				'z-index'	: 1600
			});
			self.dimLights();			
			// load the video according to video source
			switch( data.source ){
				case 'youtube':
					// load video
					if( !youtube_player ){
						youtube_player = $(video_container).YJ_YouTubeVideoPlayer({
							'video_id' 	: data.video,
							'slider' 	: self,
							'animationDuration' : options.animationDuration||500,
							'animation' : animation
						});
					}else{
						// use the already existing video
						youtube_player.loadVideo( data.video );
					}					
					
				break;
				case 'vimeo':
					if( !vimeo_player ){
						vimeo_player = $(video_container).YJ_VimeoVideoPlayer({
							'video_id' 	: data.video,
							'slider' 	: self,
							'animationDuration' : options.animationDuration||500,
							'animation' : animation
						});
					}else{
						// use the already existing video
						vimeo_player.loadVideo( data.video );
					}
				break;	
			}			
		}
		
		// toggle class on main navigation to be displayed differently when video is open
		this.rearangeMainNav = function(){
			
			if( video_playing ){
				$(navContainer).addClass('video_on').css({'opacity':0});
			}else{
				$(navContainer).removeClass('video_on').css({'opacity':1});
				self.dimLights();
			}
			
		}	
		
		// dim lights
		this.dimLights = function(){
			
			if(options.dimlights == 1 ){
				
				$('<div/>', {
					class: options.dimContainer,
					width:$(window).width(),
					height:$(window).height()
				}).appendTo('body').fadeTo(700, options.dimOpacity).click( function(e){
					
					stopVideo();
					
				});
				
							
				if( !video_playing ){
					
					$("." + options.dimContainer).fadeOut(700).remove();
				}
			}
			
		}
		// stop slider if it's on autoslide
		this.stopSlider = function(){
			stopSlider();
		}
		// restart slider if autoslide is on
		this.startSlider = function(){
			startSlider();
		}
		//modify variable video_playing to flag video playback for autoslide
		this.changeVideoStatus = function( status ){
			video_playing = status;
			if( status ){
				$(slides[currentSlide]).css({'visibility':'hidden'});
			}else{
				$(slides[currentSlide]).css({'visibility':'visible'});
			}
		}
		
		this.videoPaused = function( data ){
			video_paused = data.paused;
			if( data.paused ){
				if( $.browser.mobile ){
					$(navContainer).stop(true, true, true).animate({'opacity':1}, {queue:false, duration:200});
				}	
			}
		}
		
		// resize slider to current slide
		this.resizeToCurrent = function(){
			$(self).stop(true, true, true).animate({
				'height': getSlideHeight( currentSlide )
			}, {'queue':false, 'duration':300});
		}
		// returns current slide index
		this.playingSlides = function(){
			return switchingSlides;
		}
		
		/**
		 * Verifies if browser is Apple ipad, ipod or iphone.
		 */
		this.is_iDevice = function(){
			if( null !== options.is_iDevice ){
				return options.is_iDevice;
			}			
			return /iPhone|iPad|iPod/i.test(navigator.userAgent);			
		}
		
		return initialize();		
	};
	
	
	/**
	 * YouTube Video player plugin
	 */	
	$.fn.YJ_VimeoVideoPlayer = function( options ){
		
		if( 0 == this.length ){ 
			return false; 
		}
		
		// support multiple elements
       	if (this.length > 1){
       		this.each(function() { 
				$(this).YJ_VimeoVideoPlayer( options );				
			});
       		return;
       	}
		
		var defaults = {
			'video_id' 	: false,
			'slider'	: false,
			'animationDuration' : 500,
			'animation' : 'fade'
		};
		
		var self 			= this,
			options 		= $.extend({}, defaults, options),
			playerId		= 'yjmedia-vimeo-player-' + Math.floor(Math.random()*1000),
			protocol		= 'http:' == location.protocol ? 'http' : 'https';
		
		var initialize = function(){			
			// load the iframe API
			var params = {
				'api'		: 1, // this stays 1. enables js to interact with the player
				'title'		: 0, // show video title
				'byline'	: 0, // show video author
				'portrait'	: 0, // show author avatar
				'player_id'	: playerId
			};
			
			var src = protocol + '://player.vimeo.com/video/' + options.video_id + '?' + $.param( params );			
			var ifr = '<iframe style="visibility:visible;" id="'+playerId+'" src="' + src + '" width="100%" height="100%" frameborder="0" webkitAllowFullScreen mozallowfullscreen allowFullScreen></iframe>';
			$(self).append( $('<div/>', {
				'class' : 'yjmedia-vimeo-player',
				css: {
					'display'	:	'block',
					'position'	:	'absolute',
					'width'		:	'100%',
					'height'	:	'100%'
				}		
			}).append( ifr ) );
			
			//store slider reference on player
			var data = {
				'slider' : options.slider,
				'video_container' : self
			};
			
			$('#'+playerId).data('elements', data);
			
			return self;
		};
		
		// load a new video into the player
		this.loadVideo = function( video_id ){
			//@todo check if player is ready
	    	// load the iframe API
			var params = {
				'api'		: 1, // this stays 1. enables js to interact with the player
				'title'		: 0, // show video title
				'byline'	: 0, // show video author
				'portrait'	: 0, // show author avatar
				'player_id'	: playerId
			};
			// hack-ish way to load new video but loadVideo action is unreliable in Vimeo player
			var src = protocol + '://player.vimeo.com/video/' + video_id + '?' + $.param( params );		
	    	$('#'+playerId).attr('src', src);	    	
		};
		
		this.stopVideo = function(){
			
			var slides		= options.slider.playingSlides();
				is_slide 	= 'slide' == options.animation,
				left 		= ( slides.next < slides.current ? -1 : 1 ) * $(self).width();
				
			$(self)
				.stop(true, true, true)
				.animate( 
					{'opacity' : ( is_slide ? 1 : 0 ), 'left' : ( is_slide ? -left : 0 )}, 
					{queue:false, duration:options.animationDuration||500, complete: function(){
						$(self).css({
				 			'top' 		: -10000,
				 			'left'		: -10000,
				 			'z-index'	: 1,
				 			'opacity'	: 1
				 		});
				 		
				 		$(self).find('.yjmedia-vimeo-player').css({
				 			'top' 		: -10000,
				 			'left'		: -10000
				 		});
					}} 
				)
				.css('z-index',1);	
			
	 		options.slider.changeVideoStatus( false );
	 		options.slider.resizeToCurrent();	
	 		options.slider.startSlider();
	 		options.slider.rearangeMainNav();
	 		yjmedia_post_action('pause', null, playerId);// pause current video	 		
		};
		
		return initialize();
	}; // end of Vimeo player
	
	
	//Vimeo player messages
	//Listen for messages from the player
	if (window.addEventListener){
	  window.addEventListener('message', yjmedia_receiveMessage, false);
	}else{
	  window.attachEvent('onmessage', yjmedia_receiveMessage, false);
	}
	
	/*
	 * Receive player messages
	 */
	function yjmedia_receiveMessage(e){
		
		var getData = $.parseJSON(e.data);
		
		if( -1 == e.origin.search('player.vimeo.com')){
			return;
		}
		
		if($('.play-video').length == 0) return;
		
		if( -1 == e.origin.search('player.vimeo.com')){
			return;
		};		
		
		var data 		= $.parseJSON( e.data ),
			pid 		= data.player_id;
			elements 	= $('#'+pid).data('elements'),
			video_container = elements.video_container,
			slider			= elements.slider;
		
		switch(data.event) {
		    case 'ready':
		    	
		    	slider.find('.yjmedia-vimeo-player').css({
		 			'top' 		: 0,
		 			'left'		: 0
		 		});		
		    	
		    	// play the video	
		    	if( !slider.is_iDevice() ){
		    		yjmedia_post_action( 'play', null, pid );
				}
		    	// stop the slider
		    	slider.stopSlider();
		    	// add event listeners
		    	yjmedia_post_action('addEventListener', 'pause', pid);
		    	yjmedia_post_action('addEventListener', 'finish', pid);
		    	yjmedia_post_action('addEventListener', 'play', pid);
		    	
		    	slider.rearangeMainNav();
		    break;		    
		    
		    case 'play':	
		    	// stop the slider
		    	slider.stopSlider();
		    	slider.changeVideoStatus( true );
		    	slider.rearangeMainNav();
		    	//put player back into view
		    	slider.find('.yjmedia-vimeo-player').css({
		 			'top' 		: 0,
		 			'left'		: 0
		 		});
		    	slider.videoPaused({'player' : 'vimeo', 'paused' : false });
		    break;
		    
		    case 'pause':
		    	slider.videoPaused({'player' : 'vimeo', 'paused' : true });
		    break;	
		    
		   /*case 'pause':*/	
		    case 'finish':	
		    	
		    	// move player out of view
		    	video_container.css({
		 			'top' 		: -10000,
		 			'left'		: -10000,
		 			'z-index'	: 1
		 		});
		 		
		 		slider.find('.yjmedia-vimeo-player').css({
		 			'top' 		: -10000,
		 			'left'		: -10000
		 		});
		 		slider.changeVideoStatus( false );
		 		yjmedia_post_action('unload', null, pid);// unload current video
		 		slider.resizeToCurrent();	
		 		slider.startSlider();
		 		slider.rearangeMainNav();
		    break;
		}
	}
	
	//Helper function for sending a message to the player
	function yjmedia_post_action( action, value, pid ) {
	  var data = { method: action };
	  
	  if (value) {
	      data.value = value;
	  }
	  
	  var f = $('#'+pid)[0];	  
	 
	  f.contentWindow.postMessage(
		 JSON.stringify(data), 
		 $(f).attr('src').split('?')[0]
	  );
	}
	
	
	/**
	 * YouTube Video player plugin
	 */	
	$.fn.YJ_YouTubeVideoPlayer = function( options ){
		
		if( 0 == this.length ){ 
			return false; 
		}
		
		// support multiple elements
       	if (this.length > 1){
       		this.each(function() { 
				$(this).YJ_YouTubeVideoPlayer( options );				
			});
       		return;
       	}
		
		var defaults = {
			'video_id' 	: false,
			'slider'	: false,
			'animationDuration' : 500,
			'animation' : 'fade'
		};
		
		var self 			= this,
			options 		= $.extend({}, defaults, options),
			yt_api_loaded 	= false,
			playerId		= 'yjmedia-yt-player-' + Math.floor(Math.random()*1000),
			container_id	= 'yjmedia-youtube-player-' +  Math.floor(Math.random()*1000),
			player			= false, // holds the player reference
			protocol		= 'http:' == location.protocol ? 'http' : 'https';
		
		$(self).append(
			$('<div/>',{
				'id'  : container_id,
				'css' : {
					'display' 	: 'block',
					'position' 	: 'absolute',
					'width'		: '100%',
					'height'	: '100%',
					'top'		: 0,
					'left'		: 0
				}
			}).append(
				$('<div/>',{
					'id' : playerId	
				})
			)		
		);
		
		var initialize = function(){
			// load the iframe API
			if( !yt_api_loaded ){
				$.getScript( protocol + '://www.youtube.com/player_api' );
				yt_api_loaded = true;
			}
			
			// load the player
			if( !YJSG_YT_API_LOADED ){
				self.interval = setInterval( function(){
					loadYTplayer();
				}, 1000);
				return self;						
			}else{
				loadYTplayer();
			}
			
			return self;
		};
		
		// load YouTube HTML5 player
		var loadYTplayer = function(){
			
			if( !YJSG_YT_API_LOADED ){
				return;
			}
			
			clearInterval(self.interval);
			
			new YT.Player(playerId, {
				height		: '100%',
				width		: '100%',
				videoId		: options.video_id,
				playerVars	: {
					'enablejsapi'	: 1, // this stays 1 for youtube. enables interaction with player from js
					'modestbranding': 0, // different situations for youtube logo
					'autohide'		: 0, // controls visibility
					'controls'		: 1, // show controls
					'hd'			: 1, // hd videos
					'rel'			: 0, // show related
					'showinfo'		: 0, // show info
					'showsearch'	: 0, // show search
					'iv_load_policy': 3, // hide annotations
					'playerapiid' 	: playerId,
					'wmode'			: 'opaque'
				},
				events: {
					 'onReady': function( event ){
						 player = event.target;
						 player.setVolume( 30 );
						 if( !options.slider.is_iDevice() ){
							 player.playVideo();
						 }
						 
						 options.slider.changeVideoStatus(true);
						 options.slider.rearangeMainNav();
					 },
					 'onStateChange': function( object ){
						 var state = object.data;	
						 
						 switch( state ){
						 	case 1: // video is playing
						 		options.slider.rearangeMainNav();
						 		$('#'+container_id).css({
						 			'top' 		: 0,
						 			'left'		: 0
						 		});
						 		
						 		if( options.slider.is_iDevice() ){
						 			$('#'+playerId).css('transform', 'scale(1)');
								}
						 		
						 		options.slider.videoPaused({'player' : 'youtube', 'paused' : false });
							break;
						 	case 0: // video ended
						 	/*case 2: // video paused*/
						 		// move player out of view
						 		$(self).css({
						 			'top' 		: -10000,
						 			'left'		: -10000,
						 			'z-index'	: 1
						 		});
						 		
						 		$('#'+container_id).css({
						 			'top' 		: -10000,
						 			'left'		: -10000
						 		});
						 		
						 		player.clearVideo(); // unload current video
						 		options.slider.resizeToCurrent();
						 		options.slider.changeVideoStatus(false);
						 		options.slider.startSlider();
						 		options.slider.rearangeMainNav();
						 	break;
						 	case 2:
						 		if( options.slider.is_iDevice() ){
						 			$('#'+playerId).css('transform', 'scale(0.7)');
								}
						 		options.slider.videoPaused({'player' : 'youtube', 'paused' : true });						 		
						 	break;	
						 }						 
					 },
					 'onError': function( object ){
						 switch( object.data ){
						 	case 2 : // invalid parameter
						 		
						 	break;
						 	case 100: //video not found
						 		
						 	break;
						 	case 101: // owner doesn't allow embed
						 		
						 	break;	
						 }						 
					 }
				}
	        });			
		};
		
		// load a new video into the player
		this.loadVideo = function( video_id ){
			if( !player ){
				return;
			}
			player.loadVideoById( video_id );
			options.slider.changeVideoStatus(true);
		}
		
		this.stopVideo = function(){
			if( !player ){
				return;
			}
			player.pauseVideo();
			
			var slides		= options.slider.playingSlides();
				is_slide 	= 'slide' == options.animation,
				left 		= ( slides.next < slides.current ? -1 : 1 ) * $(self).width();
			
			$(self)
				.stop(true, true, true)
				.animate( 
					{'opacity' : ( is_slide ? 1 : 0 ), 'left' : ( is_slide ? -left : 0 )}, 
					{queue:false, duration:options.animationDuration||500, complete: function(){
						$(self).css({
				 			'top' 		: -10000,
				 			'left'		: -10000,
				 			'z-index'	: 1,
				 			'opacity'	: 1
				 		});
				 		
						$('#'+container_id).css({
				 			'top' 		: -10000,
				 			'left'		: -10000
				 		});
					}} 
				)
				.css('z-index',1);	
			
			player.clearVideo(); // unload current video
	 		options.slider.resizeToCurrent();
	 		options.slider.changeVideoStatus(false);
	 		options.slider.startSlider();
	 		options.slider.rearangeMainNav();
		}
		
		return initialize();
	}; // end of YouTube player
	
})(jQuery);

//YouTube API callback
;(function($){
	window.YJSG_YT_API_LOADED = false;
	$(document).ready(function(){
		window.onYouTubePlayerAPIReady = function(){
			YJSG_YT_API_LOADED = true;
		};		
	});	
})(jQuery);

/**
 * jQuery.browser.mobile (http://detectmobilebrowser.com/)
 *
 * jQuery.browser.mobile will be true if the browser is a mobile device
 *
 **/
(function(a){(jQuery.browser=jQuery.browser||{}).mobile=/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od|ad)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows (ce|phone)|xda|xiino/i.test(a)||/1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s\-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|\-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw\-(n|u)|c55\/|capi|ccwa|cdm\-|cell|chtm|cldc|cmd\-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc\-s|devi|dica|dmob|do(c|p)o|ds(12|\-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(\-|_)|g1 u|g560|gene|gf\-5|g\-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd\-(m|p|t)|hei\-|hi(pt|ta)|hp( i|ip)|hs\-c|ht(c(\-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i\-(20|go|ma)|i230|iac( |\-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc\-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|\-[a-w])|libw|lynx|m1\-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m\-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(\-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)\-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|\-([1-8]|c))|phil|pire|pl(ay|uc)|pn\-2|po(ck|rt|se)|prox|psio|pt\-g|qa\-a|qc(07|12|21|32|60|\-[2-7]|i\-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h\-|oo|p\-)|sdk\/|se(c(\-|0|1)|47|mc|nd|ri)|sgh\-|shar|sie(\-|m)|sk\-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h\-|v\-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl\-|tdg\-|tel(i|m)|tim\-|t\-mo|to(pl|sh)|ts(70|m\-|m3|m5)|tx\-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|\-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(\-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas\-|your|zeto|zte\-/i.test(a.substr(0,4))})(navigator.userAgent||navigator.vendor||window.opera);



(function($){var elems=$([]),timeout_id;$.event.special.resize={setup:function(){var elem=$(this);elems=elems.add(elem);elem.data("resize",{w:elem.width(),h:elem.height()});if(elems.length===1){poll()}},teardown:function(){var elem=$(this);elems=elems.not(elem);elem.removeData("resize");if(!elems.length){clearTimeout(timeout_id)}}};function poll(){elems.each(function(){var elem=$(this),width=elem.width(),height=elem.height(),data=elem.data("resize");if(width!==data.w||height!==data.h){data.w=width;data.h=height;elem.triggerHandler("resize")}});timeout_id=setTimeout(poll,250)}})(jQuery);